<?php
/*
Plugin Name: Wyde Core
Plugin URI: http://www.wydethemes.com
Description: Core Plugin for Wyde Themes
Version: 2.5
Author: Wyde
Author URI: http://www.wydethemes.com
*/

// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Current Wyde Core plugin version
 */
if ( ! defined( 'WYDE_VERSION' ) ) {
	/**
	 *
	 */
	define( 'WYDE_VERSION', '2.5' );
}

if( !class_exists( 'Wyde_Core' ) ) {
	
	class Wyde_Core {

	    /**
	     * Unique identifier for your plugin.
	     *
	     * Use this value (not the variable name) as the text domain when internationalizing strings of text. It should
	     * match the Text Domain file header in the main plugin file.
	     *
	     * @since    1.0.0
	     *
	     * @var      string
	     */
	    protected $plugin_slug = 'wyde-core';

	    /**
	     * Instance of this class.
	     *
	     * @since    1.0.0
	     *
	     * @var      object
	     */
	    protected static $instance = null;
		
		/**
		 * This method adds other methods to specific hooks within WordPress.
		 *
		 * @since     1.0.0
		 */
		public function __construct() {
			$this->constants();
			$this->init();
		}

		/**
		 * Defines plugin constants
		 *
		 * @since     2.0.0
		 */
		function constants() {        	
        	define('WYDE_PLUGIN_DIR', plugin_dir_path(__FILE__));
        	define('WYDE_PLUGIN_URI', plugin_dir_url(__FILE__));
		}

		/**
		 * Initialize the plugin by setting localization and loading public scripts
		 *
		 * @since     1.0.0
		 */
		function init() {

        	add_action( 'init', array($this, 'register_post_types') );

        	add_action( 'plugins_loaded', array($this, 'load_wyde_core_text_domain'));

			add_filter('manage_wyde_portfolio_posts_columns', array($this, 'portfolio_posts_columns') );

			add_action('manage_wyde_portfolio_posts_custom_column', array($this, 'portfolio_posts_column_content'), 10, 2);

			add_filter('manage_edit-wyde_portfolio_sortable_columns', array($this, 'portfolio_sortable_columns') );

			add_filter('posts_clauses', array($this, 'portfolio_category_sort_column'), 10, 2);

        	/** Redux Framework **/
			if (file_exists(WYDE_PLUGIN_DIR.'/inc/redux-framework/framework.php')) {
			    require_once( WYDE_PLUGIN_DIR.'/inc/redux-framework/framework.php' );
			}

			/** Wyde Importer **/
			include_once WYDE_PLUGIN_DIR. '/inc/importer/class-wyde-importer.php';

			/** Metaboxes **/
			include_once WYDE_PLUGIN_DIR. '/inc/metaboxes/init.php';

			/** Mega Menu **/
			include_once WYDE_PLUGIN_DIR. '/inc/class-wyde-mega-menu.php';
		}

	    /**
	     * Return an instance of this class.
	     *
	     * @since     1.0.0
	     *
	     * @return    object    A single instance of this class.
	     */
	    public static function get_instance() {

		    // If the single instance hasn't been set, set it now.
		    if ( null == self::$instance ) {
			    self::$instance = new self;
		    }

		    return self::$instance;
	    }

	    function load_wyde_core_text_domain() {
			load_plugin_textdomain( 'wyde-core', false, WYDE_PLUGIN_DIR . 'languages' );
		}

	    /**
		 * Register custom post types
		 *
		 * @since     1.0.0
		 */
		function register_post_types(){
		    
		    global $wyde_options, $wp_post_types;

		    $portfolio_slug = isset( $wyde_options['portfolio_slug'] ) ? $wyde_options['portfolio_slug']:'portfolio-item';

		    $wp_post_types['attachment']->exclude_from_search = true;

		    //Portfolio post type
		    register_post_type('wyde_portfolio',
				array(
					'labels' => array(
						    'name' 			=> __( 'Portfolios', 'Wyde' ),
						    'singular_name' => __( 'Portfolio', 'Wyde' ),
		                    'add_new' => __('Add New', 'Wyde' ),
		                    'add_new_item' => __('Add New Portfolio', 'Wyde'),
		                    'edit_item' => __('Edit Portfolio', 'Wyde'),
		                    'new_item' => __('New Portfolio', 'Wyde'),
		                    'view_item' => __('View Portfolios', 'Wyde'),
		                    'menu_name' => __('Portfolios', 'Wyde')
					),
					'public' => true,
					'has_archive' => false,
					'rewrite' => array(
						    'slug' => sanitize_title( $portfolio_slug )
					),
					'supports' => array( 'title', 'editor', 'thumbnail'),
					'can_export' => true,
		            'menu_icon' => 'dashicons-portfolio'
				)
			);

		    //Portfolio Category    
		    register_taxonomy('portfolio_category', 'wyde_portfolio', 
		        array(
		            'hierarchical' => true, 
		            'labels' => array(
		                    'name' => __('Portfolio Categories', 'Wyde'),
		                    'singular_name' => __('Category', 'Wyde'),
		                    'all_items' => __('All Categories', 'Wyde' ),
		                    'edit_item' => __('Edit Category', 'Wyde' ),
		                    'update_item' => __('Update Category', 'Wyde' ),
		                    'add_new_item' => __('Add New Category', 'Wyde' ),
		                    'new_item_name' => __('New Category', 'Wyde' ),
		            ),
		            //'sort' => true,
        			//'show_admin_column' => true,
		            'query_var' => true, 
		            'rewrite' => array(
						    'slug' => 'portfolio-category'
				    )
		        )
		    );

		    //Portfolio Skill   
			register_taxonomy('portfolio_skill', 'wyde_portfolio', 
		        array(
		            'hierarchical' => true, 
		            'labels' => array(
		                    'name' =>  __('Portfolio Skills', 'Wyde'),
		                    'singular_name' => __('Skill', 'Wyde'),
		                    'all_items' => __('All Skills', 'Wyde'),
		                    'edit_item' => __('Edit Skill', 'Wyde'),
		                    'update_item' =>  __('Update Skill', 'Wyde'),
		                    'add_new_item' => __('Add New Skill', 'Wyde'),
		                    'new_item_name' => __('New Skill', 'Wyde'),
		            ), 
		            'query_var' => true, 
		            'rewrite' => array(
						    'slug' => 'portfolio-skill'
				    )
		        )
		    );

		            
		    //Portfolio Tags   
			register_taxonomy('portfolio_tag', 'wyde_portfolio', 
		        array(
		            'hierarchical' => false, 
		            'labels' => array(
		                'name' => __('Portfolio Tags', 'Wyde'),
		                'singular_name' => __('Tag', 'Wyde'),
		                'all_items' => __('All Tags', 'Wyde'),
		                'edit_item' => __('Edit Tag', 'Wyde'),
		                'update_item' => __('Update Tag', 'Wyde'),
		                'add_new_item' => __('Add New Tag', 'Wyde'),
		                'new_item_name' =>  __('New Tag', 'Wyde'),
		            ), 
		            'query_var' => true, 
		            'rewrite' => array(
						'slug' => 'portfolio-tag'
				    )
		        )
		    );

			
		    //Testimonial 	
		    register_post_type('wyde_testimonial',
				array(
					'labels' => array(
						    'name' 			=> __( 'Testimonials', 'Wyde' ),
						    'singular_name' => __( 'Testimonial', 'Wyde' ),
		                    'add_new' => __('Add New', 'Wyde' ),
		                    'add_new_item' => __('Add New Testimonial', 'Wyde'),
		                    'edit_item' => __('Edit Testimonial', 'Wyde'),
		                    'new_item' => __('New Testimonial', 'Wyde'),
		                    'view_item' => __('View Testimonial', 'Wyde'),
		                    'menu_name' => __('Testimonials', 'Wyde')
					),
					'public' => true,
					'has_archive' => false,
					'rewrite' => array(
						    'slug' => 'testimonial-item'
					),
					'supports' => array( 'title'),
					'can_export' => true,
		            'exclude_from_search' => true,
		            'menu_icon' => 'dashicons-testimonial'
				)
			);
		            
		    //Testimonial Category
		    register_taxonomy('testimonial_category', 'wyde_testimonial', 
		        array(
		            'hierarchical' => true, 
		            'labels' => array(
		                    'name' => __('Testimonial Categories', 'Wyde'),
		                    'singular_name' => __('Category', 'Wyde'),
		                    'all_items' => __('All Categories', 'Wyde' ),
		                    'edit_item' => __('Edit Category', 'Wyde' ),
		                    'update_item' => __('Update Category', 'Wyde' ),
		                    'add_new_item' => __('Add New Category', 'Wyde' ),
		                    'new_item_name' => __('New Category', 'Wyde' ),
		                ),
		            'query_var' => true, 
		            'rewrite' => true
		        )
		    );

		    //Team Member
		    register_post_type('wyde_team_member', 
		        array(
					'labels' => array(
					        'name' 					=> __('Team Members', 'Wyde' ),
					        'singular_name' 		=> __('Team Member', 'Wyde' ),
					        'add_new' 				=> __('Add New', 'Wyde' ),
					        'add_new_item' 			=> __('Add New Team Member', 'Wyde' ),
					        'edit_item' 			=> __('Edit Team Member', 'Wyde' ),
					        'new_item' 				=> __('New Team Member', 'Wyde' ),
					        'all_items' 			=> __('All Team Members', 'Wyde' ),
					        'view_item' 			=> __('View Team Members', 'Wyde' ),
					        'search_items' 			=> __('Search Team Members', 'Wyde' ),
					        'parent_item_colon' 	=> '',
					        'menu_name' 			=> __( 'Team Members', 'Wyde' )
		            ),
					'public'    => true,
					'has_archive'   => false,
					'supports'  => array('title'),
		            'exclude_from_search'   => true,
					'menu_icon' => 'dashicons-groups',
		            'rewrite'   => array(
						    'slug' => 'team-member'
					),
				)
		    );


		    //Team Member Category
		    register_taxonomy('team_member_category', 'wyde_team_member', 
		        array(
		            'hierarchical' => true, 
		            'labels' => array(
		                    'name' => __('Testimonial Categories', 'Wyde'),
		                    'singular_name' => __('Category', 'Wyde'),
		                    'all_items' => __('All Categories', 'Wyde' ),
		                    'edit_item' => __('Edit Category', 'Wyde' ),
		                    'update_item' => __('Update Category', 'Wyde' ),
		                    'add_new_item' => __('Add New Category', 'Wyde' ),
		                    'new_item_name' => __('New Category', 'Wyde' ),
		                ),
		            'query_var' => true, 
		            'rewrite' => true
		        )
		    );
		        
		}

		/**
		 * Add category column to portfolio posts
		 *
		 * @since     2.1
		 */
    	function portfolio_posts_columns($columns){
		    unset($columns['date']);// temporarily remove, to have custom column before date column
		    $columns['portfolio-category'] = __('Category', 'flora');
		    $columns['date'] = __('Date', 'flora');// readd the date column
		    return $columns;
		}

		/**
		 * Set category column content
		 *
		 * @since     2.1
		 */
		function portfolio_posts_column_content($column_name, $post_id){
		    if($column_name == 'portfolio-category'){
		        echo get_the_term_list($post_id, 'portfolio_category', '', ', ', '').PHP_EOL;
		    }
		}

		/**
		 * Set category column sortable
		 *
		 * @since     2.1
		 */
		function portfolio_sortable_columns($columns){
		    $columns['portfolio-category'] = 'portfolio-category';
		    return $columns;
		}

		/**
		 * Category column custom sort
		 *
		 * @since     2.1
		 */
		function portfolio_category_sort_column($clauses, $wp_query){
    
    		global $wpdb;
    		if(isset($wp_query->query['orderby']) && $wp_query->query['orderby'] == 'portfolio-category'){
        	$clauses['join'] .= " LEFT OUTER JOIN {$wpdb->term_relationships} ON {$wpdb->posts}.ID={$wpdb->term_relationships}.object_id
			LEFT OUTER JOIN {$wpdb->term_taxonomy} USING (term_taxonomy_id)
			LEFT OUTER JOIN {$wpdb->terms} USING (term_id)";
			
        	$clauses['where'] .= "AND (taxonomy = 'portfolio_category' OR taxonomy IS NULL)";
        	$clauses['groupby'] = "object_id";
        	$clauses['orderby'] = "GROUP_CONCAT({$wpdb->terms}.name ORDER BY name ASC)";
        	if(strtoupper($wp_query->get('order')) == 'ASC'){
            $clauses['orderby'] .= 'ASC';
		        } else{
		            $clauses['orderby'] .= 'DESC';
		        }
		    }
		    return $clauses;
		}

	}

// Instantiate the class
$wyde_core = new Wyde_Core();

}